
// -*- mode: c++; c-basic-offset:4 -*-

// This file is part of libdap, A C++ implementation of the OPeNDAP Data
// Access Protocol.

// Copyright (c) 2002,2003,2005 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//         Reza Nekovei <reza@intcomm.net>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.

// (c) COPYRIGHT URI/MIT 1994-1996
// Please read the full copyright statement in the file COPYRIGHT.
//
// Authors:
//      reza            Reza Nekovei (reza@intcomm.net)

// Test the client-side library code. Build a surrogate library for a simple
// API that contains and open and close call like netcdf.
//
// jhrg 10/4/93

#include "netcdf.h"

#include <string>

#include "Connect.h"
#include "NCConnect.h"
#include "Connections.h"

Connections conns(64);

int
test_open(string name, int mode)
{
    Connect *c = new NCConnect(name, mode);

    int id = conns.add_connect(c);

    return id;
}

void
test_close(int id)
{
    delete conns[id];
    conns.del_connect(id);
}

int 
main(int argc, char *argv[])
{
    Connect *c2;
    int id;

    id = test_open(argv[1], 1);

    c2 = conns[id];

    c2->das().print();

    test_close(id);

    c2 = conns[id];		// It is an error to do this after test_close
}

// $Log: client.cc,v $
// Revision 1.4  2005/04/07 23:32:38  jimg
// Modified the limits in netcdf.h (lnetcdf/lnetcdf.h and lnetcdf/netcdf.h)
// so that we can accommodate huge files.
//
// Revision 1.3  2003/12/08 18:06:37  edavis
// Merge release-3-4 into trunk
//
// Revision 1.2  2000/10/06 01:22:03  jimg
// Moved the CVS Log entries to the ends of files.
// Modified the read() methods to match the new definition in the dap library.
// Added exception handlers in various places to catch exceptions thrown
// by the dap library.
//
// Revision 1.1  1999/07/28 00:22:45  jimg
// Added
//
// Revision 1.5  1999/05/07 23:45:33  jimg
// String --> string fixes
//
// Revision 1.4  1996/09/17 17:06:51  jimg
// Merge the release-2-0 tagged files (which were off on a branch) back into
// the trunk revision.
//
// Revision 1.3.4.2  1996/07/10 21:44:31  jimg
// Changes for version 2.06. These fixed lingering problems from the migration
// from version 1.x to version 2.x.
// Removed some (but not all) warning generated with gcc's -Wall option.
//
// Revision 1.3.4.1  1996/06/25 22:04:54  jimg
// Version 2.0 from Reza.
//
// Revision 1.3  1995/07/09  21:33:54  jimg
// Added copyright notice.
//
// Revision 1.2  1995/03/21  20:58:21  jimg
// Resolved conflicts between my (jhrg) files and those checked in by Reza.
//
// Revision 1.1  1994/10/05  18:02:16  jimg
// First version of the connection management classes.
// This commit also includes early versions of the test code.
//
